@@ -1,13 +1,12 @@
-import json
 from typing import Any, Dict, List
 
 from cognite.air._api import AIRClientError
 from cognite.air._backfilling_api import AIRBackfillingAPI, NoBackfillAPI
 from cognite.air._config import AIRClientConfig
-from cognite.air._constants import MA_FIELD_META_FIELDS, MA_FIELD_META_MODELVERSION, SA_EXT_ID, SA_FIELD_META_DATA
 from cognite.air._events_api import AIREventsAPI
 from cognite.air._time_series_api import AIRTimeSeriesAPI
-from cognite.air.utils import is_jsonable, is_string_truthy
+from cognite.air.constants import MA_FIELD_META_FIELDS, MA_FIELD_META_MODELVERSION, SA_EXT_ID, SA_FIELD_META_DATA
+from cognite.air.utils import is_string_truthy, parse_json_if_json
 from cognite.client import CogniteClient
 
 
@@ -28,8 +27,8 @@ class AIRClient:
             data_set_id=schedule_asset.data_set_id,
             schedule_asset_id=schedule_asset.id,
             schedule_asset_ext_id=sa_ext_id,
-            data_fields=json.loads(schedule_asset.metadata[SA_FIELD_META_DATA]),
-            data_fields_defs=json.loads(model_asset.metadata[MA_FIELD_META_FIELDS]),
+            data_fields=parse_json_if_json(schedule_asset.metadata.get(SA_FIELD_META_DATA)) or {},
+            data_fields_defs=parse_json_if_json(model_asset.metadata.get(MA_FIELD_META_FIELDS)) or {},
             model_name=model_asset.name,
             model_version=model_version,
         )
@@ -80,7 +79,7 @@ class AIRClient:
             err_field_names = [name for name, field in zip(field_names, fields) if field is None]
             raise ValueError(f"The following field names were not found: {err_field_names}")
 
-        return list(map(lambda fld: json.loads(fld) if is_jsonable(fld) else fld, fields))  # type: ignore
+        return list(map(parse_json_if_json, fields))  # type: ignore
 
     def retrieve_field(self, field_name: str) -> str:
         if not isinstance(field_name, str):
@@ -116,5 +115,5 @@ class AIRClient:
         if len(backfill_asset_list) == 1:
             return backfill_asset_list[0]
         raise AIRClientError(
-            f"{len(backfill_asset_list)} backfilling assets found. Expected to find exactly 1 backfilling asset"
+            f"Found {len(backfill_asset_list)} backfilling assets. Expected exactly 1 backfilling asset"
         )
