@@ -15,6 +15,12 @@ def is_jsonable(data: Union[str, bytes, bytearray]) -> bool:
         return False
 
 
+def parse_json_if_json(data: str) -> str:
+    if is_jsonable(data):
+        return json.loads(data)
+    return data
+
+
 def strip_patch_from_version(version: str) -> str:
     if not isinstance(version, str):
         raise TypeError(f"Expected input '{version}' to be of type {str}, not {type(version)}")
